@@ -14,10 +14,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""
-Nested diff command line tool.
+"""Nested diff command line tool."""
 
-"""
 import argparse
 import sys
 
@@ -26,16 +24,13 @@ import nested_diff.cli
 
 
 class App(nested_diff.cli.App):
-    """
-    Diff tool for nested data structures
+    """Diff tool for nested data structures."""
 
-    """
-    supported_ifmts = ('auto', 'ini', 'json', 'yaml')
-    supported_ofmts = ('auto', 'json', 'term', 'text', 'yaml')
+    supported_ofmts = ('auto', 'html', 'json', 'term', 'toml', 'text', 'yaml')
 
     def diff(self, a, b):
         """
-        Return diff for passed objects
+        Return diff for passed objects.
 
         :param a: First object to diff.
         :param b: Second object to diff.
@@ -104,6 +99,8 @@ class App(nested_diff.cli.App):
             return TermDumper(**kwargs)
         elif fmt == 'text':
             return TextDumper(**kwargs)
+        elif fmt == 'html':
+            return HtmlDumper(**kwargs)
 
         return super().get_dumper(fmt, **kwargs)
 
@@ -120,6 +117,8 @@ class App(nested_diff.cli.App):
 
 
 class AbstractFmtDumper(nested_diff.cli.Dumper):
+    """Base class for diff dumpers."""
+
     def encode(self, data):
         return self.encoder.format(data)
 
@@ -129,7 +128,42 @@ class AbstractFmtDumper(nested_diff.cli.Dumper):
         return opts
 
 
+class HtmlDumper(AbstractFmtDumper):
+    """Human friendly HTML dumper for nested diff."""
+
+    def __init__(self, **kwargs):
+        super().__init__()
+        from html import escape
+        from nested_diff import fmt
+        self.html_opts = {
+            'lang': 'en',
+            'title': 'Nested diff',
+        }
+        self.html_opts.update(kwargs.pop('html_opts', {}))
+
+        self.formatter = fmt.HtmlFormatter(**self.get_opts(kwargs))
+
+        if 'header' not in self.html_opts:
+            self.html_opts['header'] = (
+                '<!DOCTYPE html><html lang="' + self.html_opts['lang'] +
+                '"><head><title>' + escape(self.html_opts['title']) +
+                '</title><style>' + self.formatter.get_css() +
+                '</style></head><body>'
+            )
+        if 'footer' not in self.html_opts:
+            self.html_opts['footer'] = '</body></html>'
+
+    def encode(self, data):
+        return self.formatter.format(
+            data,
+            header=self.html_opts['header'],
+            footer=self.html_opts['footer'],
+        )
+
+
 class TermDumper(AbstractFmtDumper):
+    """Same as TextDumper but with ANSI term colors."""
+
     def __init__(self, **kwargs):
         super().__init__()
         from nested_diff import fmt
@@ -137,6 +171,8 @@ class TermDumper(AbstractFmtDumper):
 
 
 class TextDumper(AbstractFmtDumper):
+    """Human friendly text dumper for nested diff."""
+
     def __init__(self, **kwargs):
         super().__init__()
         from nested_diff import fmt
@@ -144,4 +180,5 @@ class TextDumper(AbstractFmtDumper):
 
 
 def cli():
+    """Cli tool entry point."""
     return App().run()
